@@ -18,7 +18,7 @@ dateformat="%Y-%m-%d %H:%M:%S" #the date/time is stored in this format in the re
 LogFile="/home/user/MyDocs/SleepAnalyser/SleepAnalyser.log" #Place for log file. IF YOU CHANGE THIS PATH, YOU ALSO HAVE TO CHANGE IT IN /usr/bin/sleepanalyser!
 
 translation_copyrights="English, German: George Ruinelli\n"+\
-                                     "Francais: Fred Kwame Ayanfu & Guy Roussil\n"+\
+                                     (u'Français')+": Fred Kwame Ayanfu & Guy Roussin\n"+\
                                      "Dutch: Fred Kwame Ayanful\n"+\
                                      "Chinese: "+(u'蒋岚')+" (Peter3316)"
 
@@ -196,3 +196,5 @@ WakeUp_Song=""
 WakeUp_Song_Volume=50
 WakeUp_Song_Duration=0
 WakeUp_SongIsActive=False
+
+CurrentVolume=0
