@@ -220,11 +220,6 @@ def LoadRecord():
         print "File has software version", records.SWversion
         if(records.SWversion<1.6): #workaround for old files
             print "Record is older than SW version 1.6, use old protocol"
-    #            print "Sorry, records older than SW version 1.6 are not compatible."
-    #            records.status="File version not compatible"
-    #            records.statusID="VERSION_INCOMPATIBLE"
-    #            file.close()
-    #            return 9
             records.User=string.replace(header[3].decode("utf-8") , "User:",  "")
             Startdate_date=string.replace(header[5], "Date:",  "")
             x=string.replace(header[6], "Sampling interval:",  "")
@@ -356,7 +351,7 @@ def LoadRecord():
         return 8
 
 
-    PrintRecordData()
+#    PrintRecordData()
 
 
     records.Index=0
@@ -458,4 +453,4 @@ def UpdateFileHeader():
 #            ", " +  str(records.arrData[3][i]) + ", " +  str(records.arrData[5][i])
         file.write(d+"\n")
     file.close()
-    if(data.debug==True): print "Wrote",  i +1,  "records into file"
\ No newline at end of file
+    if(data.debug==True): print "Wrote",  i +1,  "records into file"
