@@ -106,7 +106,7 @@ def GetFirstEntry():
 ###########################################################################
 ##  Process the data, generate movement indication
 ###########################################################################
-def ProcessData(ProcessAll=False, ShowFiltered=False):  #DERIVATION (ABLEITUNG)
+def ProcessData(ProcessAll=False, ShowSleepPattern=False):  #DERIVATION (ABLEITUNG)
     if(data.debug==True): print "Process Data (Process whole array:", ProcessAll,  ")"
     data.Progress="Process data..."
     lastmovebeforegraph=0
@@ -146,7 +146,7 @@ def ProcessData(ProcessAll=False, ShowFiltered=False):  #DERIVATION (ABLEITUNG)
 
 
 
-def Generate_Sleep_Pattern():
+def GenerateSleepPattern():
     #NOTE:
     #records.arrData has strings and integers mixed. This is ok in python, but does not work in C.
     #So we have to export the data and import it again afterwarts:
@@ -155,13 +155,11 @@ def Generate_Sleep_Pattern():
         arrSend[i]=records.arrData[4][i]
 
     #Exported function:
-#    arrRet=mylib.sleep_filter(arfunctions_record.pyrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, (61-data.Yscale_Sleep_Pattern)*100, data.Ysize-7, 13, data.limitMovement)
-#sleep_filter(ar, len, filter,  shift, Yscale_Movement, Yoffset, Ymax, Ymin, limitMovement)
-    arrRet=mylib.sleep_filter(arrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, data.Yscale_Sleep_Pattern, data.Yoffset_Sleep_Pattern, data.Ysize-7, 13, data.limitMovement)
+    arrRet=mylib.CalculateSleepPattern(arrSend, records.Index-data.Derivation, filter_data.arrFilter, filter_data.FilterShift, data.Yscale_Sleep_Pattern, data.Yoffset_Sleep_Pattern, data.Ysize-7, 13, data.limitMovement)
 
     for i in range(0,  records.Index-data.Derivation): #copy array and scale
         records.arrData[6][i]  = arrRet[i]
-#        print i,  records.arrData[6][i]
+
 
 
 
@@ -169,10 +167,10 @@ def Generate_Sleep_Pattern():
 
 
 ###########################################################################
-## Show (refreshs) the graph.
-## the first parameter indcates on which window it will be drawn
+## Show the graph
+## the first parameter indicates on which window it will be drawn (record window or view window
 ###########################################################################
-def DrawGraph(self,  QtGui, ShowFiltered=False):
+def DrawGraph(self,  QtGui, ShowSleepPattern=False):
     try:
         if(data.debug==True): print "Draw Graph into bitmap"
 
@@ -189,20 +187,12 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
         paint.setBrush(QtGui.QColor(data.GraphBackground))
         paint.drawRect(0,0,records.MaxArrayDataLen+10,data.GraphBitMapHeight)
 
-
-
-#        if(data.run==False):  #only draw background for sleep levels when recording is finished
         paint.setPen(QtGui.QColor(data.GraphBackground2))
         paint.setBrush(QtGui.QColor(data.GraphBackground2))
         h1=(data.Ysize-(data.Deep_Sleep_Level*data.Yscale_Movement/40))
         h2=(data.Ysize-(data.Light_Sleep_Level*data.Yscale_Movement/40))
         paint.drawRect(1, h1-6, records.MaxArrayDataLen-2, h2-h1+2)
 
-
-
-
-
-
         #Stop if data is not ok
         if(records.statusID!="OK"):#Show useful infos
             paint.setFont(QtGui.QFont('Decorative', 20))
@@ -210,13 +200,11 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
             paint.drawText(100, data.Ysize/2+5, records.status) #show status information
             return
 
-
+        #get start data
         GraphStart_tuple=Index2Tuple(0) #time of first record entry
-    #    if(data.debug==True): print "data.GraphStart",  data.GraphStart,  GraphStart_tuple
         h=int(strftime("%H", GraphStart_tuple))
         m=int(strftime("%M", GraphStart_tuple))
         s=int(strftime("%S", GraphStart_tuple))
-    #    print h,  m,  s
 
         secondsincefullhour=m*60+s
         GraphStart_seconds=Tuple2Seconds(GraphStart_tuple)
@@ -224,79 +212,44 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
         LastFullHour_tuple=Seconds2Tuple(LastFullHour_sec)
 
         h0=int(strftime("%H", LastFullHour_tuple))
-        m0=0 #int(strftime("%M", LastFullHour_tuple))
-        s0=0# int(strftime("%S", LastFullHour_tuple))
-
 
         LastFullHour_index=Tuple2Index(LastFullHour_tuple)
 
         GraphStart_index=Tuple2Index(GraphStart_tuple)
-    #    print "Indexes:",  GraphStart_index,  "(",  data.GraphStart, ")",  LastFullHour_index
 
         OffsetToLastFullHour=-1*(GraphStart_index - LastFullHour_index)/Xscale
         OffsetToLastFullHour=OffsetToLastFullHour- data.Derivation/Xscale  #Derivation takes 5 indices, so visualisation is delayed!
 
-
-
-
-
-
-
-        #DRAW main scaling lines + text
+        #main scaling lines + text
         paint.setPen(QtGui.QColor("white"))
         h=h0-2
         if(data.QuickMode==False): #normal mode
-    #        print "OffsetToLastFullHour:",  OffsetToLastFullHour
             if(data.Xscale==0): #max zoom
-    #            for i in range(OffsetToLastFullHour-decade, 781+decade,  decade): #full hours
-    #            for i in range(0, data.GraphBitMapLen,  decade): #full hours
                 for i in range(OffsetToLastFullHour-decade, max(data.GraphBitMapLen, records.Index)+decade,  decade): #full hours
-#                    h=(h0+int(i/decade)+1) % 24
                     h=(h+1) % 24
-    #                print i
                     paint.drawLine(i, data.Ysize, i, data.Ysize+10)
                     paint.setFont(QtGui.QFont('Decorative', 18))
                     paint.drawText(i-25, data.Ysize+32, str(h)+":00")
-    #                #show dashed line
-    #                paint.drawLine(i, 0, i, data.Ysize)
 
                     paint.setFont(QtGui.QFont('Decorative', 12))
                     for k in range(1, 6): #hour + k * 10 minutes
                         x=i+k*decade/6
-    #                    print " ", x,  str(h)+":"+str(10*k)
                         paint.drawLine(x, data.Ysize, x, data.Ysize+10)
                         paint.drawText(x-20, data.Ysize+26, str(h)+":"+str(10*k))
                     for m in range(1, 30): #hour + m * 2 minutes
                         x2=i+m*decade/30
-    #                    print "  ",  x2
                         paint.drawLine(x2, data.Ysize, x2, data.Ysize+4)
 
             elif(data.Xscale==1 or data.Xscale==2): #mid + min zoom
-    #            for i in range(OffsetToLastFullHour-decade, 781+decade,  decade): #full hours
                 for i in range(OffsetToLastFullHour-decade, max(data.GraphBitMapLen, records.Index)+decade,  decade): #full hours
-#                    h=(h0+int(i/decade)+1) % 24
                     h=(h+1) % 24
-    #                print i
                     paint.drawLine(i, data.Ysize, i, data.Ysize+10)
                     paint.drawText(i-15, data.Ysize+30, str(h)+":00")
-
-    #                #show dashed line
-    #                paint.setPen(QtGui.QColor("grey"))
-    #                paint.drawLine(i, 0, i, data.Ysize)
-
                     for k in range(1, 6): #hour + k * 10 minutes
                         x=i+k*decade/6
-    #                    print " ", x,  str(h)+":"+str(10*k)
                         paint.drawLine(x, data.Ysize, x, data.Ysize+4)
 
-        else: #quick mode, do not show X scale as it is not calibrated
-    #        paint.drawText(200, data.Ysize+20, "Test Mode, no time scale available")
-    #        paint.drawText((max(data.GraphBitMapLen, records.Index)-500)/Xscale, data.Ysize+20, "Test Mode, no time scale available")
-            pass
-
-
-
-        #DRAW time bars
+        #time bars
         gradient = QtGui.QLinearGradient(0, data.Ysize-11, 0, data.Ysize-1)
         p=0
         p0=0
@@ -304,7 +257,6 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
             if(records.arrData[6][p]>data.Light_Sleep_Level): #awake
                 p0=p
                 while(records.arrData[6][p]>data.Light_Sleep_Level and p<records.Index-data.Derivation): p=p+1*Xscale
-#                print p0,"-", p, records.arrData[0][p0], "-", records.arrData[0][p], "Awake"
                 gradient.setColorAt(0, QtGui.QColor(data.Awake_Color))
                 gradient.setColorAt(0.5, QtGui.QColor(data.Awake_ColorDark))
                 gradient.setColorAt(1, QtGui.QColor(data.Awake_Color))
@@ -313,34 +265,26 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
             elif(records.arrData[6][p]>data.Deep_Sleep_Level): #light sleep
                 p0=p
                 while(records.arrData[6][p]>data.Deep_Sleep_Level and records.arrData[6][p]<=data.Light_Sleep_Level and p<records.Index-data.Derivation): p=p+1*Xscale
-#                print p0,"-", p, records.arrData[0][p0], "-", records.arrData[0][p], "Light Sleep ==="
                 gradient.setColorAt(0, QtGui.QColor(data.Light_Sleep_Color))
                 gradient.setColorAt(0.5, QtGui.QColor(data.Light_Sleep_ColorDark))
                 gradient.setColorAt(1, QtGui.QColor(data.Light_Sleep_Color))
                 paint.setPen(QtGui.QColor(data.Light_Sleep_Color))
-#
+
             else:
                 p0=p
                 while(records.arrData[6][p]<=data.Deep_Sleep_Level and p<records.Index-data.Derivation): p=p+1*Xscale
-#                print p0,"-", p, records.arrData[0][p0], "-", records.arrData[0][p], "Deep Sleep ============"
                 gradient.setColorAt(0, QtGui.QColor(data.Deep_Sleep_Color))
                 gradient.setColorAt(0.5, QtGui.QColor(data.Deep_Sleep_ColorDark))
                 gradient.setColorAt(1, QtGui.QColor(data.Deep_Sleep_Color))
                 paint.setPen(QtGui.QColor(data.Deep_Sleep_Color))
-#
+
             x0=p0/Xscale
             x1=p/Xscale
             paint.setBrush(QtGui.QBrush(gradient))
             paint.drawRect(x0+1-2, data.Ysize-11, x1-x0-1, 9)
 
-
-
-
-
-
-        #DRAW movement bars (yellow)
+        #movement bars (yellow bars)
         paint.setPen(QtGui.QColor(data.MovementBarColor))
-#        peak=0
         for p in range(0,  records.Index-data.Derivation,  Xscale):
             i=p-GraphStart_index
             peak=0
@@ -348,18 +292,14 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
                 if(records.arrData[5][p+j]>peak): peak=records.arrData[5][p+j]
             x=i/Xscale
             if(peak==""): peak=0 #temporary bugfix
-#            print peak, data.Yscale_Movement, data.Ysize
             h=min(peak*data.Yscale_Movement/40,  data.Ysize-17) #cut off if higher than graph border
             paint.drawLine(x, data.Ysize-h-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
 
-
-
-
-        #DRAW sleep graph (blue)
-        if(ShowFiltered==True):
+        #sleep graph (blue graph)
+        if(ShowSleepPattern==True):
             pen=QtGui.QPen()
 
-            #filling
+            #sleep pattern filling
             pen.setColor(QtGui.QColor(19, 54, 255, 150))
             pen.setWidth(1)
             paint.setPen(pen)
@@ -369,7 +309,7 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
                 y=data.Ysize-records.arrData[6][p+Xscale]-5
                 paint.drawLine(x, data.Ysize-16,       x, y)
 
-            #outline
+            #sleep pattern outline
             pen.setColor(QtGui.QColor(19, 54, 255))
             pen.setWidth(3) #3
             paint.setPen(pen)
@@ -380,7 +320,6 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
                 y1=data.Ysize-records.arrData[6][p+Xscale]-5
                 paint.drawLine(x, y0,       x+1, y1)
 
-
        #Lucid dream option
         if(records.Use_Lucid_Dream_Song==True and records.Lucid_Dream_Song_Start_tuple!=-1):
             paint.setBrush(QtGui.QColor(data.Lucid_Dream_Color))
@@ -388,13 +327,15 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
             x0=Tuple2Index(records.Lucid_Dream_Song_Start_tuple)-data.Derivation*Xscale
             x00=(x0-GraphStart_index)/Xscale
             t=Seconds2Tuple(Tuple2Seconds(records.Lucid_Dream_Song_Start_tuple)+(records.Lucid_Dream_Song_Duration))
-            x1=Tuple2Index(t)-data.Derivation*Xscale
+            if(records.AlarmTime_tuple!=-1): end=records.AlarmTime_tuple
+            elif(records.AlarmTimeWindowEnd_tuple!=-1): end=records.AlarmTimeWindowEnd_tuple
+            else: end=t
+            x1=min(Tuple2Index(t), Tuple2Index(end))-data.Derivation*Xscale
             x01=(x1-GraphStart_index)/Xscale
             y=20
-            paint.drawPolygon(QPointF(x00, y-4), QPointF(x00, y+4), QPointF(x00+4, y))
+            paint.drawPolygon(QPointF(x00, y-6), QPointF(x00, y+6), QPointF(x00+6, y))
             paint.drawRect(x00,  y-1,  x01-x00,  2)
 
-
        #WakeUp option
         if(records.Use_WakeUp_Song==True and records.WakeUp_Song_Start_tuple!=-1):
             paint.setBrush(QtGui.QColor(data.WakeUp_Color))
@@ -402,79 +343,39 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
             x0=Tuple2Index(records.WakeUp_Song_Start_tuple)-data.Derivation*Xscale
             x00=(x0-GraphStart_index)/Xscale
             t=Seconds2Tuple(Tuple2Seconds(records.WakeUp_Song_Start_tuple)+(records.WakeUp_Song_Duration))
-            x1=Tuple2Index(t)-data.Derivation*Xscale
+            x1=min(Tuple2Index(t), Tuple2Index(records.AlarmTimeWindowEnd_tuple))-data.Derivation*Xscale
             x01=(x1-GraphStart_index)/Xscale
             y=20
-            paint.drawPolygon(QPointF(x00, y-4), QPointF(x00, y+4), QPointF(x00+4, y))
+            paint.drawPolygon(QPointF(x00, y-6), QPointF(x00, y+6), QPointF(x00+6, y))
             paint.drawRect(x00,  y-1,  x01-x00,  2)
 
-
-       #ALARM VISUALISATION
+       #alarm visualisation
         if(records.AlarmIsSet==True): #alarm time window is set, show it
             paint.setBrush(QtGui.QColor(255, 128, 0, 200))
             paint.setPen(QtGui.QColor(255, 128, 0, 200))
             x0=Tuple2Index(records.AlarmTimeWindowStart_tuple)-data.Derivation*Xscale
             x1=Tuple2Index(records.AlarmTimeWindowEnd_tuple)-data.Derivation*Xscale
-    #        x0=Tuple2Index(records.AlarmTimeWindowStart_tuple)-data.Derivation
-    #        x1=Tuple2Index(records.AlarmTimeWindowEnd_tuple)-data.Derivation
             x00=(x0-GraphStart_index)/Xscale
             x10=(x1-GraphStart_index)/Xscale
-    #        if(x00>0 or x10<780): #visible in screen
-    #            x00=max(x00,  1) #limit drawn line to border
-    #            x10=min(x10,  780) #limit drawn line to border
-    #            if(x00<x10):
-    #        print  x1,   x10
-    #        print Tuple2Index((2010, 8, 15, 20, 0, 0, 6, 227, 0)),  (Tuple2Index((2010, 8, 15, 20, 0, 0, 6, 227, 0)) -GraphStart_index)/Xscale
-    #        print ""
             paint.drawRect(x00,  8,  x10-x00,  2) #Time Window
-    #            x11=(x1+3-GraphStart_index)/Xscale
-    #            if(x11>1 and x11<779):
             paint.drawRect(x10,  4,  1,  10)  #Last Alarm opportunity
 
-
-
             if(data.AlarmIsActive==True or data.run==False): #only show alarm if alarm occured or in view mode
-    #            if(records.Index>=Tuple2Index(records.AlarmTimeWindowEnd_tuple)): #only show alarm dot when alarm really came
                 if(records.AlarmTime_seconds!=-1):
-#                    print "AlarmTimeWindowEnd:",  records.AlarmTimeWindowEnd_seconds,  "AlarmTime:",  records.AlarmTime_seconds,  "records.EndTime_seconds:",records.EndTime_seconds
-    #                EndTime_seconds=Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000
                     if(records.EndTime_seconds>=records.AlarmTime_seconds-60): #alarm got set off during recording (-60 is workaround)
-#                        paint.setBrush(QtGui.QColor(data.AlarmColor))
                         paint.setPen(QtGui.QColor(178, 0, 0))
-                        if(records.AlarmTimeWindowEnd_seconds<=records.AlarmTime_seconds):
-#                            print "Alarm due end of alarm time window"
+                        if(records.AlarmTimeWindowEnd_seconds<=records.AlarmTime_seconds): #Alarm due end of alarm time window
                             a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation*Xscale
-                        else:
-#                            print "alarm due movement"
+                        else: #alarm due movement
                             a0=Tuple2Index(records.AlarmTime_tuple)-data.Derivation
                         a00=(a0-GraphStart_index)/Xscale
 
-#                        gradient = QtGui.QRadialGradient(200,  100,  5)
                         gradient = QtGui.QRadialGradient(a00,  20,  3)
                         gradient.setColorAt(0, QtGui.QColor(255, 152, 152))
                         gradient.setColorAt(1, QtGui.QColor(255, 0, 0))
                         paint.setBrush(QtGui.QBrush(gradient))
-
-#                        paint.drawEllipse(100, 0, 200, 200)
                         paint.drawEllipse(a00-5, 15, 10, 10)
 
-            #            print "AlarmTimeWindow:",  x1,  x10,  "Alarm:",  a0,  a00
-#                    else:
-#                        print "Alarm set, but never occured"
-
-
-
-
-
-
-
-
-
-
-
-
-
-
         #DRAW Trigger line
         if(records.AlarmIsSet==True or data.QuickMode==True): #alarm time window is set, show it
             if(records.statusID=="OK"):
@@ -497,13 +398,10 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
                     y=y+17
                 paint.drawText(data.GraphBitMapLen-31, y-19, str(t)) #Trigger level
 
-
-        #show parameters (for debugging)
-        paint.setFont(QtGui.QFont('Decorative', 8))
-        paint.setPen(QtGui.QColor("gray"))
-        paint.drawText(data.GraphBitMapLen-70, data.Ysize+12, str(data.Yscale_Movement)+", "+str(data.Yscale_Sleep_Pattern)+", "+str(data.Yoffset_Sleep_Pattern)) #settings (for debbigging)
-
-
+##        #show parameters (for debugging)
+##        paint.setFont(QtGui.QFont('Decorative', 8))
+##        paint.setPen(QtGui.QColor("gray"))
+##        paint.drawText(data.GraphBitMapLen-70, data.Ysize+12, str(data.Yscale_Movement)+", "+str(data.Yscale_Sleep_Pattern)+", "+str(data.Yoffset_Sleep_Pattern)) #settings (for debbigging)
 
         #Draw border around graph
         paint.setPen(QtGui.QColor("white"))
@@ -512,20 +410,6 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
         paint.drawLine(0, 0, data.GraphBitMapLen-1, 0)  #top
         paint.drawLine(0, data.Ysize, data.GraphBitMapLen-1, data.Ysize)  #bottom
 
-    #    #show Graph border with gradient background
-#        paint.setPen(QtGui.QColor("white"))
-#        paint.setBrush(QtGui.QColor(10, 10, 10, 200))
-#        gradient = QtGui.QLinearGradient(0, 0, 0, data.Ysize)
-#        gradient.setColorAt(0, QtGui.QColor(255, 255, 255, 50)) #top
-#        gradient.setColorAt(0.5, QtGui.QColor(255, 255, 255, 0)) #bottom
-#        paint.setBrush(QtGui.QBrush(gradient))
-#        paint.drawRect(0,0,data.GraphBitMapLen-1,data.Ysize)
-
-
-
-
-
-
         #When in test mode, make noise if last moveent is over trigger level
         if(data.QuickMode==True): MakeNoise_if_over_trigger(records.arrData[6][records.Index-data.Derivation-1])
 
@@ -538,16 +422,9 @@ def DrawGraph(self,  QtGui, ShowFiltered=False):
 
 
 
-
-
-
-
-
-
-
-
-
-
+###########################################################################
+## Make noise if sleep pattern is over trigge rlevel (quick mode only)
+###########################################################################
 #TODO: improve function!!!!
 def MakeNoise_if_over_trigger(peak):
     #beep in test mode
@@ -567,39 +444,19 @@ def MakeNoise_if_over_trigger(peak):
 
 
 ###########################################################################
-##
+## Draw statistic bars
 ###########################################################################
 def DrawStatistic(self,  QtGui, QtCore):
-#    try:
-#        if(daDta.debug==1): print "Draw Graph into bitmap"
-
     paint = QtGui.QPainter()
     paint.begin(self)
 
     #clear whole pitmap (remove old data)
     paint.setPen(QtGui.QColor(data.GraphBackground))
-#    paint.setBrush(QtGui.QColor("red"))
-#    paint.drawRect(0, 0, data.StatisticsBitMapLen/2,  data.StatisticsBitMapHeight/2)
-
     paint.setBrush(QtGui.QColor(data.GraphBackground))
-#    paint.setBrush(QtGui.QColor(255, 255, 255, 50))
-#    paint.setBrush(QtCore.Qt.NoBrush)
     paint.drawRect(0, 0, data.StatisticsBitMapLen,  data.StatisticsBitMapHeight)
 
-#    paint.
-
-#    linearGrad = QtGui.QLinearGradient(10, 10, 20, 20)
-#    linearGrad.setColorAt(0, QtGui.QColor("red"))
-#    linearGrad.setColorAt(1, QtGui.QColor("green"))
-
-
-
-#    paint.setBrush(QtGui.QGradient())
-
     paint.setPen(QtGui.QColor(data.GraphBackground))
 
-
-
     if(records.arrStatData[0][3]>0): #Awake
         gradient = QtGui.QLinearGradient(0, 20, 0, 30)
         gradient.setColorAt(0, QtGui.QColor(data.Awake_Color))
@@ -630,68 +487,70 @@ def DrawStatistic(self,  QtGui, QtCore):
     paint.end()
 
 
+
 ###########################################################################
-##
+##Generate data for statistics
 ###########################################################################
 def GenerateStatisticData():
-    for i in range(0, 4): #clear array
-        for j in range(0,  3): records.arrStatData[j][i]=0
+#    for i in range(0, 4): #clear array
+#        for j in range(0,  3): records.arrStatData[j][i]=0
 
+    #NOTE:
+    #records.arrData has strings and integers mixed. This is ok in python, but does not work in C.
+    #So we have to export the data and import it again afterwarts:
+    arrSend=[0]*(records.Index+len(filter_data.arrFilter))
+    for i in range(0,  records.Index-data.Derivation): #copy array
+        arrSend[i]=records.arrData[6][i]
 
+    records.arrStatData=mylib.CalculateStatistic(arrSend, records.Index-data.Derivation, records.EndTime_seconds-records.StartTime_seconds, records.Sampling_interval*records.Value_smoothing/1000, data.Light_Sleep_Level, data.Deep_Sleep_Level)
 
-
-    p=0
-    p0=0
-    while(p<records.Index-data.Derivation):
-        if(records.arrData[6][p]>data.Light_Sleep_Level): #awake
-            p0=p
-            while(records.arrData[6][p]>data.Light_Sleep_Level and p<records.Index-data.Derivation): p=p+1
-            records.arrStatData[0][0]=records.arrStatData[0][0]+p-p0 #Accumulated time for Awake
-            records.arrStatData[0][1]=records.arrStatData[0][1]+1 #Amount of times in Awake
-            if(records.arrStatData[0][2]<p-p0): records.arrStatData[0][2]=p-p0 #Max time in Awake
-
-        elif(records.arrData[6][p]>data.Deep_Sleep_Level): #light sleep
-            p0=p
-            while(records.arrData[6][p]>data.Deep_Sleep_Level and records.arrData[6][p]<=data.Light_Sleep_Level and p<records.Index-data.Derivation): p=p+1
-            records.arrStatData[1][0]=records.arrStatData[1][0]+p-p0 #Accumulated time for Light sleep
-            records.arrStatData[1][1]=records.arrStatData[1][1]+1#Amount of times in Light sleep
-            if(records.arrStatData[1][2]<p-p0): records.arrStatData[1][2]=p-p0 #Max time in Light sleep
-
-        else:
-            p0=p
-            while(records.arrData[6][p]<=data.Deep_Sleep_Level and p<records.Index-data.Derivation): p=p+1
-            records.arrStatData[2][0]=records.arrStatData[2][0]+p-p0 #Accumulated time for Deep sleep
-            records.arrStatData[2][1]=records.arrStatData[2][1]+1#Amount of times in Deep sleep
-            if(records.arrStatData[2][2]<p-p0): records.arrStatData[2][2]=p-p0 #Max time in Deep sleep
-
-
-#    print "Statistic data:",  records.arrStatData
-
-    #Accumulated time/phase
-    records.arrStatData[0][0]=records.arrStatData[0][0]*records.Sampling_interval*records.Value_smoothing/1000
-    records.arrStatData[1][0]=records.arrStatData[1][0]*records.Sampling_interval*records.Value_smoothing/1000
-    records.arrStatData[2][0]=records.arrStatData[2][0]*records.Sampling_interval*records.Value_smoothing/1000
-
-
-    #Max time/phase
-    records.arrStatData[0][2]=records.arrStatData[0][2]*records.Sampling_interval*records.Value_smoothing/1000
-    records.arrStatData[1][2]=records.arrStatData[1][2]*records.Sampling_interval*records.Value_smoothing/1000
-    records.arrStatData[2][2]=records.arrStatData[2][2]*records.Sampling_interval*records.Value_smoothing/1000
-
-
-    #time percent
-    t_total=(records.EndTime_seconds-records.StartTime_seconds)
-    if(t_total==0):  t_total=1 #division by zero prevention
-    records.arrStatData[0][3]=records.arrStatData[0][0]*100/t_total
-    records.arrStatData[1][3]=records.arrStatData[1][0]*100/t_total
-    records.arrStatData[2][3]=records.arrStatData[2][0]*100/t_total
+#    p=0
+#    p0=0
+#    while(p<records.Index-data.Derivation):
+#        if(records.arrData[6][p]>data.Light_Sleep_Level): #awake
+#            p0=p
+#            while(records.arrData[6][p]>data.Light_Sleep_Level and p<records.Index-data.Derivation): p=p+1
+#            records.arrStatData[0][0]=records.arrStatData[0][0]+p-p0 #Accumulated time for Awake
+#            records.arrStatData[0][1]=records.arrStatData[0][1]+1 #Amount of times in Awake
+#            if(records.arrStatData[0][2]<p-p0): records.arrStatData[0][2]=p-p0 #Max time in Awake
+#
+#        elif(records.arrData[6][p]>data.Deep_Sleep_Level): #light sleep
+#            p0=p
+#            while(records.arrData[6][p]>data.Deep_Sleep_Level and records.arrData[6][p]<=data.Light_Sleep_Level and p<records.Index-data.Derivation): p=p+1
+#            records.arrStatData[1][0]=records.arrStatData[1][0]+p-p0 #Accumulated time for Light sleep
+#            records.arrStatData[1][1]=records.arrStatData[1][1]+1#Amount of times in Light sleep
+#            if(records.arrStatData[1][2]<p-p0): records.arrStatData[1][2]=p-p0 #Max time in Light sleep
+#
+#        else:
+#            p0=p
+#            while(records.arrData[6][p]<=data.Deep_Sleep_Level and p<records.Index-data.Derivation): p=p+1
+#            records.arrStatData[2][0]=records.arrStatData[2][0]+p-p0 #Accumulated time for Deep sleep
+#            records.arrStatData[2][1]=records.arrStatData[2][1]+1#Amount of times in Deep sleep
+#            if(records.arrStatData[2][2]<p-p0): records.arrStatData[2][2]=p-p0 #Max time in Deep sleep
+#
+#    #Accumulated time/phase
+#    records.arrStatData[0][0]=records.arrStatData[0][0]*records.Sampling_interval*records.Value_smoothing/1000
+#    records.arrStatData[1][0]=records.arrStatData[1][0]*records.Sampling_interval*records.Value_smoothing/1000
+#    records.arrStatData[2][0]=records.arrStatData[2][0]*records.Sampling_interval*records.Value_smoothing/1000
+#
+#    #Max time/phase
+#    records.arrStatData[0][2]=records.arrStatData[0][2]*records.Sampling_interval*records.Value_smoothing/1000
+#    records.arrStatData[1][2]=records.arrStatData[1][2]*records.Sampling_interval*records.Value_smoothing/1000
+#    records.arrStatData[2][2]=records.arrStatData[2][2]*records.Sampling_interval*records.Value_smoothing/1000
+#
+#    #time percent
+#    t_total=(records.EndTime_seconds-records.StartTime_seconds)
+#    if(t_total==0):  t_total=1 #division by zero prevention
+#    records.arrStatData[0][3]=records.arrStatData[0][0]*100/t_total
+#    records.arrStatData[1][3]=records.arrStatData[1][0]*100/t_total
+#    records.arrStatData[2][3]=records.arrStatData[2][0]*100/t_total
 
     if(data.debug==True): print "Statistic data:",  records.arrStatData
 
 
 
 ###########################################################################
-##
+## Initialise all variables in record container
 ###########################################################################
 def InitRecord():
     records.Index=0
@@ -739,17 +598,8 @@ def InitRecord():
 
 
 
-
-
-
-
-
-
-
-
 ###########################################################################
-##
-## Only used for debugging
+## Print out all data of record container
 ###########################################################################
 def PrintRecordData(ShowArray=True):
     print "###################### RECORD DATA #######################"
@@ -787,10 +637,8 @@ def PrintRecordData(ShowArray=True):
     print "WakeUp_Song_Duration:",  records.WakeUp_Song_Duration
     print "WakeUp_Song_Volume:",  records.WakeUp_Song_Volume
 
-
-
     if(ShowArray==True):
         for i in range(0, records.Index): #print data of  records
             print records.arrData[0][i],  records.arrData[1][i],  records.arrData[2][i],  records.arrData[3][i],  records.arrData[4][i],  records.arrData[5][i],  records.arrData[6][i]
 
-    print "##########################################################"
+    print "##########################################################"
\ No newline at end of file
