@@ -29,7 +29,7 @@ arrStatData=[[0]*4,  [0]*4,  [0]*4]
     # Light sleep
     # Deep Sleep
 #field 2:
-    # Accumulated time/phase, Amount of times/phase, Max time/phase, time percent
+    # Accumulated time/phase,    Amount of times/phase,    Max time/phase,    Time percent
 
 
 
@@ -65,3 +65,17 @@ Sample_smoothing=-1
 Value_smoothing=-1
 
 Trigger=-1
+
+
+Use_Lucid_Dream_Song = False
+Lucid_Dream_Song_Start_tuple = -1
+Lucid_Dream_Song = ""
+Lucid_Dream_Song_Delay = -1
+Lucid_Dream_Song_Duration = -1
+Lucid_Dream_Song_Volume = -1
+
+Use_WakeUp_Song = False
+WakeUp_Song_Start_tuple = -1
+WakeUp_Song = ""
+WakeUp_Song_Duration = -1
+WakeUp_Song_Volume= -1
